@@ -44,11 +44,17 @@ class MintDesktop:
         if self.marco_section is not None:
             self.marco_section.hide()
         self.metacity_section.hide()
+        self.mutter_section.hide()
+        self.xfwm4_section.hide()
         self.compiz_section.hide()
         if "marco" in wm:
             self.marco_section.show()
         elif "metacity" in wm:
             self.metacity_section.show()
+        elif "mutter" in wm:
+            self.mutter_section.show()
+        elif "xfwm4" in wm:
+            self.xfwm4_section.show()
         elif "compiz" in wm and os.path.exists("/usr/bin/ccsm"):
             self.compiz_section.show()
             self.compiz_reset_button.set_sensitive(os.path.exists(self.compiz_path))
@@ -56,6 +62,12 @@ class MintDesktop:
     def help_button_clicked(self, widget):
         Popen(["xdg-open", "help:mintdesktop"])
 
+    def xfwm4_settings_button_clicked(self, widget):
+        Popen(["xfwm4-settings"])
+
+    def xfwm4_tweaks_button_clicked(self, widget):
+        Popen(["xfwm4-tweaks-settings"])
+
     def compiz_settings_button_clicked(self, widget):
         Popen(["ccsm"])
 
@@ -128,8 +140,7 @@ class MintDesktop:
             page.show_all()
 
         # WM page
-        size_group = Gtk.SizeGroup()
-        size_group.set_mode(Gtk.SizeGroupMode.HORIZONTAL)
+        size_group = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
 
         vbox = self.builder.get_object("vbox_wm")
         page = SettingsPage()
@@ -161,6 +172,8 @@ class MintDesktop:
             options.append(["openbox", _("Openbox")])
             if compton:
                 options.append(["openbox-compton", _("Openbox + Compton")])
+        if os.path.exists("/usr/bin/mutter"):
+            options.append(["mutter", _("Mutter")])
         if os.path.exists("/usr/bin/compiz"):
             options.append(["compiz", _("Compiz")])
         if os.path.exists("/usr/bin/awesome"):
@@ -195,15 +208,30 @@ class MintDesktop:
 
         self.metacity_section = page.add_section(_("Metacity settings"))
         self.metacity_section.add_row(GSettingsSwitch(_("Use system font in titlebar"), "org.gnome.desktop.wm.preferences", "titlebar-uses-system-font"))
+        self.metacity_section.add_row(GSettingsSwitch(_("Don't show window content while dragging them"), "org.gnome.metacity", "reduced-resources"))
         self.metacity_section.add_row(GSettingsComboBox(_("Buttons layout:"), "org.gnome.desktop.wm.preferences", "button-layout", button_options, size_group=size_group))
 
-        self.compiz_section = page.add_section(_("Compiz settings"))
+        self.mutter_section = page.add_section(_("Mutter settings"))
+        if os.path.exists("/usr/bin/mutter"):
+            self.mutter_section.add_row(GSettingsSwitch(_("Use system font in titlebar"), "org.gnome.desktop.wm.preferences", "titlebar-uses-system-font"))
+            self.mutter_section.add_row(GSettingsSwitch(_("Place new windows in the center of the screen"), "org.gnome.mutter", "center-new-windows"))
+            self.mutter_section.add_row(GSettingsSwitch(_("Automatically maximize nearly screen sized windows"), "org.gnome.mutter", "auto-maximize"))
+            self.mutter_section.add_row(GSettingsSwitch(_("Enable edge tiling when dropping windows on screen edges"), "org.gnome.mutter", "edge-tiling"))
+            self.mutter_section.add_row(GSettingsComboBox(_("Buttons layout:"), "org.gnome.desktop.wm.preferences", "button-layout", button_options, size_group=size_group))
 
-        button = Gtk.Button(_("Configure Compiz"))
+        self.xfwm4_section = page.add_section(_("Xfwm4 settings"))
+        self.xfwm4_settings_button = Gtk.Button(label=_("Configure Xfwm4"))
+        self.xfwm4_settings_button.connect("clicked", self.xfwm4_settings_button_clicked)
+        self.xfwm4_section.add_row(self.xfwm4_settings_button)
+        self.xfwm4_tweaks_button = Gtk.Button(label=_("Tweak Xfwm4"))
+        self.xfwm4_tweaks_button.connect("clicked", self.xfwm4_tweaks_button_clicked)
+        self.xfwm4_section.add_row(self.xfwm4_tweaks_button)
+
+        self.compiz_section = page.add_section(_("Compiz settings"))
+        button = Gtk.Button(label=_("Configure Compiz"))
         button.connect("clicked", self.compiz_settings_button_clicked)
         self.compiz_section.add_row(button)
-
-        self.compiz_reset_button = Gtk.Button(_("Reset Compiz settings"))
+        self.compiz_reset_button = Gtk.Button(label=_("Reset Compiz settings"))
         self.compiz_reset_button.connect("clicked", self.compiz_reset_button_clicked)
         self.compiz_section.add_row(self.compiz_reset_button)
 
